create_kernels_in_program

Function create_kernels_in_program 

pub fn create_kernels_in_program(
    program: *mut c_void,
) -> Result<Vec<*mut c_void>, i32>
Create OpenCL kernel objects for all kernel functions in a program. Calls clCreateKernelsInProgram to create OpenCL kernel objects.

  • program - a valid OpenCL program.

returns a Result containing the new OpenCL kernel objects or the error code from the OpenCL C API function.