pub unsafe fn release_mem_object(memobj: *mut c_void) -> Result<(), i32>Expand description
Release an OpenCL memory object.
Calls clReleaseMemObject to decrement the memory object reference count.
memobj- theOpenCLmemory object.
returns an empty Result or the error code from the OpenCL C API function.
Safety
This function is unsafe because it changes the OpenCL object reference count.